@@ -2,11 +2,14 @@
  * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
  * Copyright (C) 2009 - DIGITEO - Antoine ELIAS
  *
- * This file must be used under the terms of the CeCILL.
- * This source file is licensed as described in the file COPYING, which
- * you should have received as part of this distribution.  The terms
- * are also available at
- * http://www.cecill.info/licences/Licence_CeCILL_V2.1-en.txt
+ * Copyright (C) 2012 - 2016 - Scilab Enterprises
+ *
+ * This file is hereby licensed under the terms of the GNU GPL v2.0,
+ * pursuant to article 5.3.4 of the CeCILL v.2.1.
+ * This file was originally licensed under the terms of the CeCILL v2.1,
+ * and continues to be available under such terms.
+ * For more information, see the COPYING file which you should have received
+ * along with this program.
  */
 
 #ifndef __INTERNAL_COMMON_API__
@@ -35,16 +38,6 @@ void createNamedVariable(int *_piVarID);
 */
 int updateLstk(int _iNewPos, int _iSCIDataAddress, int _iVarSize);
 
-/**
-*
-* @param[in]
-* @param[in]
-* @param[in]
-* @param[in]
-* @return
-*/
-int updateInterSCI(int _iVar, char _cType, int _iSCIAddress, int _iSCIDataAddress);
-
 /**
 * @param[in] _piAddress variable address
 * @param[in] _iType type to check
@@ -65,8 +58,5 @@ int checkNamedVarType(void* _pvCtx, const char *_pstName, int _iType);
 */
 int checkNamedVarFormat(void* _pvCtx, const char *_pstName);
 
-
-SciErr sciErrInit();
-
 #endif /* __INTERNAL_COMMON_API__ */
 
