@@ -2,18 +2,20 @@
  * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
  * Copyright (C) 2009-2010 - DIGITEO
  *
- * This file must be used under the terms of the CeCILL.
- * This source file is licensed as described in the file COPYING, which
- * you should have received as part of this distribution. The terms
- * are also available at
- * http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
+ * Copyright (C) 2012 - 2016 - Scilab Enterprises
+ *
+ * This file is hereby licensed under the terms of the GNU GPL v2.0,
+ * pursuant to article 5.3.4 of the CeCILL v.2.1.
+ * This file was originally licensed under the terms of the CeCILL v2.1,
+ * and continues to be available under such terms.
+ * For more information, see the COPYING file which you should have received
+ * along with this program.
  *
  */
 
 #include "api_scilab.h"
-#include "MALLOC.h"
 
-int sci_deleteNamedVariable(char *fname, unsigned long fname_len)
+int sci_deleteNamedVariable(char *fname, void* pvApiCtx)
 {
     SciErr sciErr;
     int iRet = 0;
@@ -41,6 +43,7 @@ int sci_deleteNamedVariable(char *fname, unsigned long fname_len)
         iRet = deleteNamedVariable(pvApiCtx, pstVarName);
     }
 
+    freeAllocatedSingleString(pstVarName);
     createScalarBoolean(pvApiCtx, Rhs + 1, iRet);
     AssignOutputVariable(pvApiCtx, 1) = Rhs + 1;
     return 0;
