@@ -2,11 +2,14 @@
  * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
  * Copyright (C) 2009-2010 - DIGITEO
  *
- * This file must be used under the terms of the CeCILL.
- * This source file is licensed as described in the file COPYING, which
- * you should have received as part of this distribution. The terms
- * are also available at
- * http://www.cecill.info/licences/Licence_CeCILL_V2.1-en.txt
+ * Copyright (C) 2012 - 2016 - Scilab Enterprises
+ *
+ * This file is hereby licensed under the terms of the GNU GPL v2.0,
+ * pursuant to article 5.3.4 of the CeCILL v.2.1.
+ * This file was originally licensed under the terms of the CeCILL v2.1,
+ * and continues to be available under such terms.
+ * For more information, see the COPYING file which you should have received
+ * along with this program.
  *
  */
 #include <stdlib.h>
@@ -14,9 +17,9 @@
 #include "Scierror.h"
 #include "localization.h"
 #include "sciprint.h"
-#include "MALLOC.h"
+#include "sci_malloc.h"
 
-int read_pointer(char *fname, unsigned long fname_len)
+int read_pointer(char *fname, void* pvApiCtx)
 {
     SciErr sciErr;
 
@@ -26,7 +29,7 @@ int read_pointer(char *fname, unsigned long fname_len)
     if (nbInputArgument(pvApiCtx) == 0)
     {
         //create mode
-        double* pdblData    = (double*)malloc(sizeof(double) * 2 * 2);
+        double* pdblData    = (double*)MALLOC(sizeof(double) * 2 * 2);
         pdblData[0]			= 1;
         pdblData[1]			= 3;
         pdblData[2]			= 2;
@@ -54,6 +57,7 @@ int read_pointer(char *fname, unsigned long fname_len)
         }
         pdblData = (double*)pvPtr;
         sciErr = createMatrixOfDouble(pvApiCtx, nbInputArgument(pvApiCtx) + 1, 2, 2, pdblData);
+        FREE(pvPtr);
     }
     else
     {
