@@ -2,11 +2,14 @@
  * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
  * Copyright (C) 2009-2010 - DIGITEO
  *
- * This file must be used under the terms of the CeCILL.
- * This source file is licensed as described in the file COPYING, which
- * you should have received as part of this distribution. The terms
- * are also available at
- * http://www.cecill.info/licences/Licence_CeCILL_V2.1-en.txt
+ * Copyright (C) 2012 - 2016 - Scilab Enterprises
+ *
+ * This file is hereby licensed under the terms of the GNU GPL v2.0,
+ * pursuant to article 5.3.4 of the CeCILL v.2.1.
+ * This file was originally licensed under the terms of the CeCILL v2.1,
+ * and continues to be available under such terms.
+ * For more information, see the COPYING file which you should have received
+ * along with this program.
  *
  */
 
@@ -14,9 +17,9 @@
 #include "Scierror.h"
 #include "localization.h"
 #include "sciprint.h"
-#include "MALLOC.h"
+#include "sci_malloc.h"
 
-int write_string(char *fname, unsigned long fname_len)
+int write_string(char *fname, void* pvApiCtx)
 {
     SciErr sciErr;
     //variable info : matrix of string 2 x 3
@@ -31,7 +34,7 @@ int write_string(char *fname, unsigned long fname_len)
     char string13[]	= "puffin";
     char string23[]	= "you";
     //alloc new array
-    pstData			= (char**)malloc(sizeof(char*) * iRows * iCols);
+    pstData			= (char**)MALLOC(sizeof(char*) * iRows * iCols);
     //copy data address to the "main" array
     pstData[0]		= string11;
     pstData[1]		= string21;
@@ -42,14 +45,14 @@ int write_string(char *fname, unsigned long fname_len)
 
     //create the variable
     sciErr = createMatrixOfString(pvApiCtx, nbInputArgument(pvApiCtx) + 1, iRows, iCols, pstData);
+    //free container
+    FREE(pstData);
     if (sciErr.iErr)
     {
         printError(&sciErr, 0);
         return 0;
     }
 
-    //free container
-    free(pstData);
     //assign allocated variables to Lhs position
     AssignOutputVariable(pvApiCtx, 1) = nbInputArgument(pvApiCtx) + 1;
     return 0;
