@@ -2,16 +2,21 @@
  * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
  * Copyright (C) ????-2008 - INRIA
  *
- * This file must be used under the terms of the CeCILL.
- * This source file is licensed as described in the file COPYING, which
- * you should have received as part of this distribution.  The terms
- * are also available at
- * http://www.cecill.info/licences/Licence_CeCILL_V2.1-en.txt
+ * Copyright (C) 2012 - 2016 - Scilab Enterprises
+ *
+ * This file is hereby licensed under the terms of the GNU GPL v2.0,
+ * pursuant to article 5.3.4 of the CeCILL v.2.1.
+ * This file was originally licensed under the terms of the CeCILL v2.1,
+ * and continues to be available under such terms.
+ * For more information, see the COPYING file which you should have received
+ * along with this program.
  *
  */
 
 #include <math.h>
 #include <string.h>
+
+#include "doublecomplex.h"
 #include "api_scilab.h"
 #include "gw_arnoldi.h"
 #include "core_math.h"
@@ -27,7 +32,7 @@ extern int C2F(zneupd)(int * rvec, char * howmny, int * select,
                        doublecomplex * workd, doublecomplex * workl,
                        int * lworkl, double * rwork, int * info);
 /*--------------------------------------------------------------------------*/
-int sci_zneupd(char *fname, unsigned long fname_len)
+int sci_zneupd(char *fname, void *pvApiCtx)
 {
     SciErr sciErr;
 
@@ -76,15 +81,12 @@ int sci_zneupd(char *fname, unsigned long fname_len)
     doublecomplex* pWORKL   = NULL;
 
     int mRVEC,     nRVEC;
-    int mHOWMANY,  nHOWMANY;
     int mSELECT,   nSELECT;
     int D,        mD,        nD;
     int Z,        mZ,        nZ;
     int mSIGMA,    nSIGMA;
     int mWORKev,   nWORKev;
-    int mBMAT,     nBMAT;
     int mN,        nN;
-    int mWHICH,    nWHICH;
     int mNEV,      nNEV;
     int mTOL,      nTOL;
     int RESID,    mRESID,    nRESID;
@@ -409,19 +411,19 @@ int sci_zneupd(char *fname, unsigned long fname_len)
     LDZ = LDV;
 
     /* Check some sizes */
-    if (mIPARAM*nIPARAM != 11)
+    if (mIPARAM * nIPARAM != 11)
     {
         Scierror(999, _("%s: Wrong size for input argument %s: An array of size %d expected.\n"), fname, "IPARAM", 11);
         return 1;
     }
 
-    if (mIPNTR*nIPNTR != 14)
+    if (mIPNTR * nIPNTR != 14)
     {
         Scierror(999, _("%s: Wrong size for input argument %s: An array of size %d expected.\n"), fname, "IPNTR", 14);
         return 1;
     }
 
-    if (mRESID*nRESID != pN[0])
+    if (mRESID * nRESID != pN[0])
     {
         Scierror(999, _("%s: Wrong size for input argument %s: An array of size %d expected.\n"), fname, "RESID", pN[0]);
         return 1;
@@ -433,13 +435,13 @@ int sci_zneupd(char *fname, unsigned long fname_len)
         return 1;
     }
 
-    if (mSELECT*nSELECT != pNCV[0])
+    if (mSELECT * nSELECT != pNCV[0])
     {
         Scierror(999, _("%s: Wrong size for input argument %s: An array of size %d expected.\n"), fname, "SELECT", pNCV[0]);
         return 1;
     }
 
-    if (mD*nD != (pNEV[0] + 1))
+    if (mD * nD != (pNEV[0] + 1))
     {
         Scierror(999, _("%s: Wrong size for input argument %s: An array of size %d expected.\n"), fname, "D", pNEV[0] + 1);
         return 1;
@@ -451,7 +453,7 @@ int sci_zneupd(char *fname, unsigned long fname_len)
         return 1;
     }
 
-    if (mWORKev*nWORKev != 2 * pNCV[0])
+    if (mWORKev * nWORKev != 2 * pNCV[0])
     {
         Scierror(999, _("%s: Wrong size for input argument %s: An array of size %d expected.\n"), fname, "WORKev", 2 * pNCV[0]);
         return 1;
@@ -481,7 +483,7 @@ int sci_zneupd(char *fname, unsigned long fname_len)
     // Retrieve a matrix of double at position 2.
     if (getAllocatedSingleString(pvApiCtx, piAddrpHOWMANY, &pHOWMANY))
     {
-        Scierror(202, _("%s: Wrong type for argument #%d: A string expected.\n"), fname, 2);
+        Scierror(202, _("%s: Wrong type for argument #%d: string expected.\n"), fname, 2);
         return 1;
     }
 
@@ -497,7 +499,7 @@ int sci_zneupd(char *fname, unsigned long fname_len)
     if (getAllocatedSingleString(pvApiCtx, piAddrpBMAT, &pBMAT))
     {
         freeAllocatedSingleString(pHOWMANY);
-        Scierror(202, _("%s: Wrong type for argument #%d: A string expected.\n"), fname, 8);
+        Scierror(202, _("%s: Wrong type for argument #%d: string expected.\n"), fname, 8);
         return 1;
     }
 
@@ -515,7 +517,7 @@ int sci_zneupd(char *fname, unsigned long fname_len)
     {
         freeAllocatedSingleString(pHOWMANY);
         freeAllocatedSingleString(pBMAT);
-        Scierror(202, _("%s: Wrong type for argument #%d: A string expected.\n"), fname, 10);
+        Scierror(202, _("%s: Wrong type for argument #%d: string expected.\n"), fname, 10);
         return 1;
     }
 
@@ -532,7 +534,7 @@ int sci_zneupd(char *fname, unsigned long fname_len)
 
     if (pINFO[0] < 0)
     {
-        C2F(errorinfo)("zneupd", pINFO, 6L);
+        Scierror(998, _("%s: internal error, info=%d.\n"), fname, *pINFO);
         return 0;
     }
 
