@@ -24,18 +24,6 @@
 EXTERN_AST wchar_t *getSCIHOMEW(void);
 EXTERN_AST char *getSCIHOME(void);
 
-EXTERN_AST void setSCIHOMEW(const wchar_t* _sci_path);
-EXTERN_AST void setSCIHOME(const char* _sci_path);
-
-EXTERN_AST wchar_t* computeSCIHOMEW();
-EXTERN_AST char* computeSCIHOME();
-
-EXTERN_AST wchar_t* getenvSCIHOMEW(void);
-EXTERN_AST char* getenvSCIHOME(void);
-
-EXTERN_AST void putenvSCIHOMEW(const wchar_t* _sci_path);
-EXTERN_AST void putenvSCIHOME(const char* _sci_path);
-
 EXTERN_AST void defineSCIHOME();
 
 #endif // ! __SCI_HOME_H__
