@@ -161,7 +161,7 @@ ArrayOf<T>* ArrayOf<T>::insert(typed_list* _pArgs, InternalType* _pSource)
                             status = false;
                             break;
                         }
-                        
+
                         m_pRealData[i] = *pRealData;
                         ++pRealData;
                     }
@@ -758,6 +758,7 @@ ArrayOf<T>* ArrayOf<T>::append(int _iRows, int _iCols, InternalType* _poSource)
         return pIT;
     }
 
+    _poSource->IncreaseRef();
     ArrayOf * pGT = _poSource->getAs<ArrayOf>();
     int iRows = pGT->getRows();
     int iCols = pGT->getCols();
@@ -775,7 +776,7 @@ ArrayOf<T>* ArrayOf<T>::append(int _iRows, int _iCols, InternalType* _poSource)
     }
     else if (isComplex())
     {
-        pGT->setComplex(true);
+        pGT = pGT->setComplex(true);
     }
 
     if (pGT->isComplex())
@@ -800,6 +801,9 @@ ArrayOf<T>* ArrayOf<T>::append(int _iRows, int _iCols, InternalType* _poSource)
         }
     }
 
+    pGT->killMe();
+    _poSource->DecreaseRef();
+
     return this;
 }
 
@@ -1641,6 +1645,7 @@ ArrayOf<T>* ArrayOf<T>::resize(int* _piDims, int _iDims)
                 int iNewIdx = getIndexWithDims(piIndexes, _piDims, _iDims);
                 pRealData[iNewIdx] = m_pRealData[i];
                 m_pRealData[i] = NULL;
+
                 for (int j = iPreviousNewIdx; j < iNewIdx; ++j)
                 {
                     T pTemp = getNullValue();
