@@ -2,11 +2,14 @@
  * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
  * Copyright (C) 2007 - INRIA - Allan CORNET
  *
- * This file must be used under the terms of the CeCILL.
- * This source file is licensed as described in the file COPYING, which
- * you should have received as part of this distribution.  The terms
- * are also available at
- * http://www.cecill.info/licences/Licence_CeCILL_V2.1-en.txt
+ * Copyright (C) 2012 - 2016 - Scilab Enterprises
+ *
+ * This file is hereby licensed under the terms of the GNU GPL v2.0,
+ * pursuant to article 5.3.4 of the CeCILL v.2.1.
+ * This file was originally licensed under the terms of the CeCILL v2.1,
+ * and continues to be available under such terms.
+ * For more information, see the COPYING file which you should have received
+ * along with this program.
  *
  */
 
@@ -21,7 +24,7 @@
  * @param[out] sizeArrayReturned
  * @return an array of chars
  */
-COMPLETION_IMPEXP char **completion(char *somechars, int *sizeArrayReturned);
+COMPLETION_IMPEXP char **completion(const char *somechars, int *sizeArrayReturned);
 
 /**
 * completion function on Functions for scilab
@@ -29,7 +32,7 @@ COMPLETION_IMPEXP char **completion(char *somechars, int *sizeArrayReturned);
 * @param[out] sizeArrayReturned
 * @return an array of chars
 */
-COMPLETION_IMPEXP char **completionOnFunctions(char *somechars, int *sizeArrayReturned);
+COMPLETION_IMPEXP char **completionOnFunctions(const char *somechars, int *sizeArrayReturned);
 
 /**
 * completion function on command words for scilab
@@ -37,7 +40,7 @@ COMPLETION_IMPEXP char **completionOnFunctions(char *somechars, int *sizeArrayRe
 * @param[out] sizeArrayReturned
 * @return an array of chars
 */
-COMPLETION_IMPEXP char **completionOnCommandWords(char *somechars, int *sizeArrayReturned);
+COMPLETION_IMPEXP char **completionOnCommandWords(const char *somechars, int *sizeArrayReturned);
 
 /**
 * completion function on Macros in libraries for scilab
@@ -45,7 +48,7 @@ COMPLETION_IMPEXP char **completionOnCommandWords(char *somechars, int *sizeArra
 * @param[out] sizeArrayReturned
 * @return an array of chars
 */
-COMPLETION_IMPEXP char **completionOnMacros(char *somechars, int *sizeArrayReturned);
+COMPLETION_IMPEXP char **completionOnMacros(const char *somechars, int *sizeArrayReturned);
 
 /**
 * completion function on Variables for scilab
@@ -53,7 +56,7 @@ COMPLETION_IMPEXP char **completionOnMacros(char *somechars, int *sizeArrayRetur
 * @param[out] sizeArrayReturned
 * @return an array of chars
 */
-COMPLETION_IMPEXP char **completionOnVariables(char *somechars, int *sizeArrayReturned);
+COMPLETION_IMPEXP char **completionOnVariables(const char *somechars, int *sizeArrayReturned);
 
 /**
 * completion function on Variables for scilab
@@ -62,7 +65,7 @@ COMPLETION_IMPEXP char **completionOnVariables(char *somechars, int *sizeArrayRe
 * @param[out] sizeArrayReturned
 * @return an array of chars
 */
-COMPLETION_IMPEXP char **completionOnVariablesWithoutMacros(char *somechars, int *sizeArrayReturned);
+COMPLETION_IMPEXP char **completionOnVariablesWithoutMacros(const char *somechars, int *sizeArrayReturned);
 
 /**
 * completion function on files for scilab
@@ -70,7 +73,7 @@ COMPLETION_IMPEXP char **completionOnVariablesWithoutMacros(char *somechars, int
 * @param[out] sizeArrayReturned
 * @return an array of chars
 */
-COMPLETION_IMPEXP char **completionOnFiles(char *somechars, int *sizeArrayReturned);
+COMPLETION_IMPEXP char **completionOnFiles(const char *somechars, int *sizeArrayReturned);
 
 /**
 * completion function on files for scilab
@@ -86,6 +89,6 @@ COMPLETION_IMPEXP char **completionOnFields(char *lineBeforeCaret, char *pattern
 * @param[out] sizeArrayReturned
 * @return an array of chars
 */
-COMPLETION_IMPEXP char **completionOnHandleGraphicsProperties(char *somechars, int *sizeArrayReturned);
+COMPLETION_IMPEXP char **completionOnHandleGraphicsProperties(const char *somechars, int *sizeArrayReturned);
 /*--------------------------------------------------------------------------*/
 #endif /* __COMPLETION_H__ */
