@@ -2,34 +2,36 @@
  * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
  * Copyright (C) 2007 - INRIA - Allan CORNET
  *
- * This file must be used under the terms of the CeCILL.
- * This source file is licensed as described in the file COPYING, which
- * you should have received as part of this distribution.  The terms
- * are also available at
- * http://www.cecill.info/licences/Licence_CeCILL_V2.1-en.txt
+ * Copyright (C) 2012 - 2016 - Scilab Enterprises
+ *
+ * This file is hereby licensed under the terms of the GNU GPL v2.0,
+ * pursuant to article 5.3.4 of the CeCILL v.2.1.
+ * This file was originally licensed under the terms of the CeCILL v2.1,
+ * and continues to be available under such terms.
+ * For more information, see the COPYING file which you should have received
+ * along with this program.
  *
  */
 #include <string.h>
 #include <stdlib.h>
 #include "completion.h"
-#include "MALLOC.h"
+#include "sci_malloc.h"
 #include "getvariablesname.h"
 #include "commandwords.h"
-#include "getfunctionslist.h"
-#include "getmacrosdictionary.h"
+#include "getfunctionsname.h"
+#include "getmacrosname.h"
 #include "completion_generic.h"
 #include "getfilesdictionary.h"
 #include "getfieldsdictionary.h"
 #include "getDictionarySetProperties.h"
 #include "getDictionaryGetProperties.h"
 #include "toolsdictionary.h"
-#if _MSC_VER
-#include "strdup_windows.h"
-#endif
+#include "os_string.h"
+#include "stdio.h"
 /*--------------------------------------------------------------------------*/
-char **completionOnDictionary(char **dictionary, int sizedictionary, char *somechars, int *sizearrayreturned);
+char **completionOnDictionary(char **dictionary, int sizedictionary, const char *somechars, int *sizearrayreturned);
 /*--------------------------------------------------------------------------*/
-char **completion(char *somechars, int *sizeArrayReturned)
+char **completion(const char *somechars, int *sizeArrayReturned)
 {
     char **ListWords = NULL;
 
@@ -90,21 +92,24 @@ char **completion(char *somechars, int *sizeArrayReturned)
         ListWords = completionOnDictionary(dictionary, sizedictionary, somechars, sizeArrayReturned);
         freePointerDictionary(dictionary, sizedictionary);
     }
+    freePointerDictionary(completionvariables, sizecompletionvariables);
+    freePointerDictionary(completionmacros, sizecompletionmacros);
+    freePointerDictionary(completionhandlegraphicsproperties, sizecompletionhandlegraphicsproperties);
+    freePointerDictionary(completionfunctions, sizecompletionfunctions);
 
     return ListWords;
 }
 /*--------------------------------------------------------------------------*/
-char **completionOnFunctions(char *somechars, int *sizeArrayReturned)
+char **completionOnFunctions(const char *somechars, int *sizeArrayReturned)
 {
     char **ListWords = NULL;
     char **dictionary = NULL;
     int sizedictionary = 0;
 
-    dictionary = GetFunctionsList(&sizedictionary);
+    dictionary = getFunctionsName(&sizedictionary);
 
     if (dictionary)
     {
-        dictionary = SortDictionary(dictionary, sizedictionary);
         ListWords = completionOnDictionary(dictionary, sizedictionary, somechars, sizeArrayReturned);
         freePointerDictionary(dictionary, sizedictionary);
     }
@@ -115,7 +120,7 @@ char **completionOnFunctions(char *somechars, int *sizeArrayReturned)
     return ListWords;
 }
 /*--------------------------------------------------------------------------*/
-char **completionOnCommandWords(char *somechars, int *sizeArrayReturned)
+char **completionOnCommandWords(const char *somechars, int *sizeArrayReturned)
 {
     char **ListWords = NULL;
     char **dictionary = NULL;
@@ -126,7 +131,6 @@ char **completionOnCommandWords(char *somechars, int *sizeArrayReturned)
     if (dictionary)
     {
         dictionary = SortDictionary(dictionary, sizedictionary);
-        dictionary = RemoveDuplicateDictionary(dictionary, &sizedictionary);
         ListWords = completionOnDictionary(dictionary, sizedictionary, somechars, sizeArrayReturned);
         freePointerDictionary(dictionary, sizedictionary);
     }
@@ -137,18 +141,16 @@ char **completionOnCommandWords(char *somechars, int *sizeArrayReturned)
     return ListWords;
 }
 /*--------------------------------------------------------------------------*/
-char **completionOnMacros(char *somechars, int *sizeArrayReturned)
+char **completionOnMacros(const char *somechars, int *sizeArrayReturned)
 {
     char **ListWords = NULL;
     char **dictionary = NULL;
     int sizedictionary = 0;
 
-    dictionary = getmacrosdictionary(&sizedictionary);
+    dictionary = getMacrosName(&sizedictionary);
 
     if (dictionary)
     {
-        dictionary = SortDictionary(dictionary, sizedictionary);
-        dictionary = RemoveDuplicateDictionary(dictionary, &sizedictionary);
         ListWords = completionOnDictionary(dictionary, sizedictionary, somechars, sizeArrayReturned);
         freePointerDictionary(dictionary, sizedictionary);
     }
@@ -159,21 +161,20 @@ char **completionOnMacros(char *somechars, int *sizeArrayReturned)
     return ListWords;
 }
 /*--------------------------------------------------------------------------*/
-char **completionOnVariables(char *somechars, int *sizeArrayReturned)
+char **completionOnVariables(const char *somechars, int *sizeArrayReturned)
 {
+    int i = 0;
     char **ListWords = NULL;
     char **dictionary = NULL;
     int sizedictionary = 0;
-
     dictionary = getVariablesName(&sizedictionary, TRUE);
-
     ListWords = completionOnDictionary(dictionary, sizedictionary, somechars, sizeArrayReturned);
     freePointerDictionary(dictionary, sizedictionary);
 
     return ListWords;
 }
 /*--------------------------------------------------------------------------*/
-char **completionOnVariablesWithoutMacros(char *somechars, int *sizeArrayReturned)
+char **completionOnVariablesWithoutMacros(const char *somechars, int *sizeArrayReturned)
 {
     int i = 0;
     int j = 0;
@@ -192,8 +193,7 @@ char **completionOnVariablesWithoutMacros(char *somechars, int *sizeArrayReturne
         char **dictionaryMacros = NULL;
         int sizedictionaryMacros = 0;
 
-        dictionaryMacros = getmacrosdictionary(&sizedictionaryMacros);
-        dictionaryMacros = SortDictionary(dictionaryMacros, sizedictionaryMacros);
+        dictionaryMacros = getMacrosName(&sizedictionaryMacros);
 
         /* Search if we have more than one definition */
         for ( i = 0; i < sizedictionaryVariables; i++)
@@ -220,7 +220,7 @@ char **completionOnVariablesWithoutMacros(char *somechars, int *sizeArrayReturne
                     /* do a copy of dictionary of Variables */
                     for ( i = 0; i < sizedictionaryVariables; i++)
                     {
-                        ListWordsTmp[i] = strdup(dictionaryVariables[i]);
+                        ListWordsTmp[i] = os_strdup(dictionaryVariables[i]);
                     }
 
                     for ( i = 0; i < sizedictionaryVariables; i++)
@@ -242,7 +242,7 @@ char **completionOnVariablesWithoutMacros(char *somechars, int *sizeArrayReturne
                         {
                             if (ListWordsTmp[i])
                             {
-                                ListWords[k] = strdup(ListWordsTmp[i]);
+                                ListWords[k] = os_strdup(ListWordsTmp[i]);
                                 if (k <= sizeListWords)
                                 {
                                     k++;
@@ -274,7 +274,12 @@ char **completionOnVariablesWithoutMacros(char *somechars, int *sizeArrayReturne
         }
         else
         {
-            ListWords = dictionaryVariables;
+            ListWords = (char**)MALLOC(sizeof(char*) * (sizedictionaryVariables + 1));
+            for ( i = 0; i < sizedictionaryVariables; i++ )
+            {
+                ListWords[i] = os_strdup(dictionaryVariables[i]);
+            }
+            ListWords[sizedictionaryVariables] = 0x0;
             *sizeArrayReturned = sizedictionaryVariables;
         }
 
@@ -285,11 +290,12 @@ char **completionOnVariablesWithoutMacros(char *somechars, int *sizeArrayReturne
         ListWords = NULL;
         *sizeArrayReturned = 0;
     }
+    freePointerDictionary(dictionaryVariables, sizedictionaryVariables);
 
     return ListWords;
 }
 /*--------------------------------------------------------------------------*/
-char **completionOnFiles(char *somechars, int *sizeArrayReturned)
+char **completionOnFiles(const char *somechars, int *sizeArrayReturned)
 {
     char **ListWords = NULL;
     char **dictionary = NULL;
@@ -332,7 +338,7 @@ char **completionOnFields(char *lineBeforeCaret, char *pattern, int *sizeArrayRe
     return ListWords;
 }
 /*--------------------------------------------------------------------------*/
-char **completionOnHandleGraphicsProperties(char *somechars, int *sizeArrayReturned)
+char **completionOnHandleGraphicsProperties(const char *somechars, int *sizeArrayReturned)
 {
     char **ListWords = NULL;
     char **dictionary = NULL;
@@ -377,10 +383,12 @@ char **completionOnHandleGraphicsProperties(char *somechars, int *sizeArrayRetur
     {
         *sizeArrayReturned = 0;
     }
+    freePointerDictionary(HandleGraphicsSetPropertiesDictionary, sizeHandleGraphicsSetPropertiesDictionary);
+    freePointerDictionary(HandleGraphicsGetPropertiesDictionary, sizeHandleGraphicsGetPropertiesDictionary);
     return ListWords;
 }
 /*--------------------------------------------------------------------------*/
-char **completionOnDictionary(char **dictionary, int sizedictionary, char *somechars, int *sizearrayreturned)
+char **completionOnDictionary(char **dictionary, int sizedictionary, const char *somechars, int *sizearrayreturned)
 {
     char **ListWords = NULL;
 
