@@ -18,7 +18,7 @@
 #include "CallScilabBridge.hxx"
 /*--------------------------------------------------------------------------*/
 using namespace  org_scilab_modules_gui_bridge;
-BOOL SetConsolePrompt(char *Sci_prompt)
+BOOL SetConsolePrompt(const char *Sci_prompt)
 {
     CallScilabBridge::setPrompt(getScilabJavaVM(), Sci_prompt);
     return TRUE;
