@@ -1,17 +1,25 @@
 /*
  * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
  * Copyright (C) 2006 - INRIA
- * 
- * This file must be used under the terms of the CeCILL.
- * This source file is licensed as described in the file COPYING, which
- * you should have received as part of this distribution.  The terms
- * are also available at    
- * http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
+ *
+ * Copyright (C) 2012 - 2016 - Scilab Enterprises
+ *
+ * This file is hereby licensed under the terms of the GNU GPL v2.0,
+ * pursuant to article 5.3.4 of the CeCILL v.2.1.
+ * This file was originally licensed under the terms of the CeCILL v2.1,
+ * and continues to be available under such terms.
+ * For more information, see the COPYING file which you should have received
+ * along with this program.
  *
  */
 
 #ifndef __BASE_MATH_H__
 #define __BASE_MATH_H__
+
+#ifdef _MSC_VER
+#define NOMINMAX
+#endif
+
 #include <limits.h>
 #include <math.h>
 
@@ -19,27 +27,33 @@
 #include <stdlib.h>
 #endif
 
-#ifndef _MSC_VER 
-#endif
 
-#ifdef _MSC_VER 
-		#include <float.h>
-		#define finite(x) _finite(x) 
+#ifdef _MSC_VER     //windows
+#include <float.h>
+#define finite(x) _finite(x)
+#else               //linux & mac
+#ifdef __cplusplus // C++
+#define finite(x) std::isfinite(x)
+#endif
 #endif /* _MSC_VER */
 
-#ifdef _MSC_VER 
-	#include <float.h>
-	#define ISNAN(x) _isnan(x)
-#else 
-	#define ISNAN(x) isnan(x)
-#endif 
+#ifdef _MSC_VER     // windows
+#include <float.h>
+#define ISNAN(x) _isnan(x)
+#else
+#ifndef __cplusplus // C
+#define ISNAN(x) isnan(x)
+#else //C++
+#define ISNAN(x) std::isnan(x)
+#endif
+#endif
 
 #define Abs(x) ( ( (x) >= 0) ? (x) : -( x) )
 #ifndef Min
 #define Min(x,y)	(((x)<(y))?(x):(y))
-#endif 
+#endif
 
-#ifndef Max 
+#ifndef Max
 #define Max(x,y)	(((x)>(y))?(x):(y))
 #endif
 
@@ -53,41 +67,37 @@
 #define DEG2RAD(x) ((x) * PI_OVER_180  )
 #define RAD2DEG(x) ((x) * _180_OVER_PI )
 
-#ifdef round
-#undef round
-#endif
-
-#define		round(a)	(int)(((a)<0.0)?(a)-.5:(a)+.5)
+#define scilab_round(a)	(int)(((a)<0.0)?(a)-.5:(a)+.5)
 #define EPSILON 1.0e-13
 
 
-/** 
-  if we suppose that the x transmited is in the range of integers 
+/**
+  if we suppose that the x transmited is in the range of integers
   we could also use :
   #define inint(x) (( x > 0 ) ? ((int) (x + 0.5)) : ((int) (x - 0.5));
  **/
 
-#define linint(x) ((int)  floor(x + 0.5 )) 
-#define inint(x) ((int) floor(x + 0.5 ))  
+#define linint(x) ((int)  floor(x + 0.5 ))
+#define inint(x) ((int) floor(x + 0.5 ))
 
-#if (defined(sun) && defined(SYSV)) 
+#if (defined(sun) && defined(SYSV))
 #include <ieeefp.h>
 #endif
 
 #if defined(_MSC_VER)
-  #define M_PI 3.14159265358979323846
+#define M_PI 3.14159265358979323846
 #else
-  #if defined(HAVE_VALUES_H)
-    #include <values.h>
-  #else
-    #if defined(HAVE_LIMITS_H)
-     #include <limits.h>
-    #endif
-  #endif
+#if defined(HAVE_VALUES_H)
+#include <values.h>
+#else
+#if defined(HAVE_LIMITS_H)
+#include <limits.h>
+#endif
+#endif
 #endif
 
 #ifndef M_PI
-#define M_PI 3.14159265358979323846 
+#define M_PI 3.14159265358979323846
 #endif
 
 #ifndef HAVE_EXP10
