@@ -2,11 +2,14 @@
 * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
 * Copyright (C) 2009 - DIGITEO - Allan CORNET
 *
-* This file must be used under the terms of the CeCILL.
-* This source file is licensed as described in the file COPYING, which
-* you should have received as part of this distribution.  The terms
-* are also available at
-* http://www.cecill.info/licences/Licence_CeCILL_V2.1-en.txt
+ * Copyright (C) 2012 - 2016 - Scilab Enterprises
+ *
+ * This file is hereby licensed under the terms of the GNU GPL v2.0,
+ * pursuant to article 5.3.4 of the CeCILL v.2.1.
+ * This file was originally licensed under the terms of the CeCILL v2.1,
+ * and continues to be available under such terms.
+ * For more information, see the COPYING file which you should have received
+ * along with this program.
 *
 */
 /*--------------------------------------------------------------------------*/
@@ -38,7 +41,7 @@ int *transposeMatrixInt(int C, int L, int *MatrixInt);
 * param[in] MatrixStr
 * return transposed matrix
 */
-char **transposeMatrixStrings(int C, int L, char **MatrixStr);
+//char **transposeMatrixStrings(int C,int L,char **MatrixStr);
 
 #endif /* __TRANSPOSEMATRIX_H__ */
 /*--------------------------------------------------------------------------*/
