@@ -3,29 +3,27 @@
  * Copyright (C) INRIA
  * Copyright (C) ENPC
  *
- * This file must be used under the terms of the CeCILL.
- * This source file is licensed as described in the file COPYING, which
- * you should have received as part of this distribution.  The terms
- * are also available at
- * http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
+ * Copyright (C) 2012 - 2016 - Scilab Enterprises
+ *
+ * This file is hereby licensed under the terms of the GNU GPL v2.0,
+ * pursuant to article 5.3.4 of the CeCILL v.2.1.
+ * This file was originally licensed under the terms of the CeCILL v2.1,
+ * and continues to be available under such terms.
+ * For more information, see the COPYING file which you should have received
+ * along with this program.
  *
  */
 #include <stdio.h>
 #include <string.h>
 #include <wchar.h>
-#include "banier.h"
 #include "csignal.h"
-#include "sigbas.h"
-#include "scilabmode.h"
+#include "configvariable_interface.h"
 #include "getKey.h"
-#include "cliPrompt.h"
-#include "cliDisplayManagement.h"
-
 /* If CTRL-C was pressed. */
 void controlC_handler(int sig)
 {
-    int j = SIGINT;
-    C2F(sigbas)(&j);
+    setTokenInteruptExecution(DO_NOT_SEND_COMMAND);
+    setExecutionBreak();
 }
 
 int csignal(void)
@@ -48,6 +46,5 @@ int csignal(void)
         return -1;
     }
 #endif
-
     return 0;
 }
