@@ -148,6 +148,14 @@ int StartScilabEngine(ScilabEngineInfo* _pSEI)
     int iMainRet = 0;
     ConfigVariable::setStartProcessing(true);
 
+    // Update scihome from command line
+    if (_pSEI->pstSciHome && strcmp(_pSEI->pstSciHome, "") != 0)
+    {
+        wchar_t* w = to_wide_string(_pSEI->pstSciHome);
+        ConfigVariable::setSCIHOME(w);
+        FREE(w);
+    }
+
     // ignore -e argument if the command is empty
     if (_pSEI->pstExec && strcmp(_pSEI->pstExec, "") == 0)
     {
@@ -286,8 +294,7 @@ int StartScilabEngine(ScilabEngineInfo* _pSEI)
     }
 
     //set prompt value
-    int pause = 0;
-    C2F(setprlev) (&pause);
+    setPreviousLevel(0);
 
     //load gateways
     if (LoadModules() == false)
@@ -712,7 +719,7 @@ void* scilabReadAndStore(void* param)
             int pause = ConfigVariable::getPauseLevel();
 
             //set prompt value
-            C2F(setprlev) (&pause);
+           setPreviousLevel(pause);
 
             if (scilabRead() == 0)
             {
