@@ -7,11 +7,14 @@
  * Copyright (C) 2007-2008 - INRIA - Bruno JOFRET
  * Copyright (C) 2011 - Calixte DENIZET
  *
- * This file must be used under the terms of the CeCILL.
- * This source file is licensed as described in the file COPYING, which
- * you should have received as part of this distribution.  The terms
- * are also available at
- * http://www.cecill.info/licences/Licence_CeCILL_V2.1-en.txt
+ * Copyright (C) 2012 - 2016 - Scilab Enterprises
+ *
+ * This file is hereby licensed under the terms of the GNU GPL v2.0,
+ * pursuant to article 5.3.4 of the CeCILL v.2.1.
+ * This file was originally licensed under the terms of the CeCILL v2.1,
+ * and continues to be available under such terms.
+ * For more information, see the COPYING file which you should have received
+ * along with this program.
  *
  */
 
@@ -122,7 +125,10 @@ public class Scilab {
          * they must be set before creating GUI
          */
         setJOGLFlags();
-        SwingView.registerSwingView();
+        /* Mode GUI */
+        if(mode == 2) {
+            SwingView.registerSwingView();
+        }
 
         /*
          * if not API mode
