@@ -2,11 +2,14 @@
  * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
  * Copyright (C) 2006-2008 - INRIA - Allan CORNET
  *
- * This file must be used under the terms of the CeCILL.
- * This source file is licensed as described in the file COPYING, which
- * you should have received as part of this distribution.  The terms
- * are also available at
- * http://www.cecill.info/licences/Licence_CeCILL_V2.1-en.txt
+ * Copyright (C) 2012 - 2016 - Scilab Enterprises
+ *
+ * This file is hereby licensed under the terms of the GNU GPL v2.0,
+ * pursuant to article 5.3.4 of the CeCILL v.2.1.
+ * This file was originally licensed under the terms of the CeCILL v2.1,
+ * and continues to be available under such terms.
+ * For more information, see the COPYING file which you should have received
+ * along with this program.
  *
  */
 
@@ -18,8 +21,8 @@
 /*--------------------------------------------------------------------------*/
 DATA_STRUCTURES_IMPEXP int gw_data_structures2(void);
 /*--------------------------------------------------------------------------*/
-int sci_getfield(char *fname, unsigned long fname_len);
-int sci_setfield(char *fname, unsigned long fname_len);
+//int sci_getfield(char *fname,unsigned long fname_len);
+//int sci_setfield(char *fname,unsigned long fname_len);
 /*--------------------------------------------------------------------------*/
 #endif /*  __GW_DATA_STRUCTURES2__ */
 /*--------------------------------------------------------------------------*/
