@@ -975,8 +975,7 @@ c-----------------------------------------------------------------------
 c the following card is for optimized compilation on lll compilers.
 clll. optimize
 c-----------------------------------------------------------------------
-      
-      include 'stack.h'
+
       external prja, solsy
       integer illin, init, lyh, lewt, lacor, lsavf, lwm, liwm,
      1   mxstep, mxhnil, nhnil, ntrep, nslast, nyh, iowns
@@ -1010,12 +1009,14 @@ c in subroutines lsoda, stoda, and prja.  groups of variables are
 c replaced by dummy arrays in the common declarations in routines
 c where those variables are not used.
 c-----------------------------------------------------------------------
+cDEC$ ATTRIBUTES DLLIMPORT:: /ls0001/
       common /ls0001/ tret, rowns(209),
      1   ccmax, el0, h, hmin, hmxi, hu, rc, tn, uround,
      2   illin, init, lyh, lewt, lacor, lsavf, lwm, liwm,
      3   mxstep, mxhnil, nhnil, ntrep, nslast, nyh, iowns(6),
      4   icf, ierpj, iersl, jcur, jstart, kflag, l, meth, miter,
      5   maxord, maxcor, msbp, mxncf, n, nq, nst, nfe, nje, nqu
+cDEC$ ATTRIBUTES DLLIMPORT:: /lsa001/
       common /lsa001/ tsw, rowns2(20), pdnorm,
      1   insufr, insufi, ixpr, iowns2(2), jtyp, mused, mxordn, mxords
 c
