@@ -2,9 +2,9 @@ c     ====================================
       subroutine rkqc(y,dydx,n,x,htry,eps,yscal,hdid,hnext,derivs,rwork)
 C      implicit undefined (a-z)
 c ................................................................
-c .   Subroutine rkqc is a fifth-order Runge-Kutta step with 
+c .   Subroutine rkqc is a fifth-order Runge-Kutta step with
 c .   monitoring of local truncation error to ensure accuracy
-c .   and adjust stepsize.   
+c .   and adjust stepsize.
 c .
 c .   Inputs:
 c .   y(1:n) = the dependent variable vector
@@ -12,21 +12,20 @@ c .   dydx(1:n) = deriv of y wrt x at starting value of indep var x
 c .   htry = attempted step size
 c .   eps = required accuracy
 c .   yscal(1:n) = scaling vector for the error
-c .   
+c .
 c .   Outputs:
 c .   y = new value of y
 c .   x = new value of x
 c .   hdid = actual stepsize accomplished
-c .   hnext = estimated next stepsize   
+c .   hnext = estimated next stepsize
 c .
-c .   derivs is the user-supplied subroutine that computes the 
+c .   derivs is the user-supplied subroutine that computes the
 c .    right-hand side derivatives
 c ................................................................
 c
 c     The original version has been modified to replace statically
 c     allocated arrays dysav, ytemp and ysav by rwork arguments parts
 c     array + blas use. Serge Steer INRIA- feb 2012
-
       integer n,i
       double precision fcor,one,safety,errcon
       parameter (fcor=.0666666667,one=1.0,safety=0.9,errcon=6.e-4)
@@ -36,15 +35,13 @@ c     array + blas use. Serge Steer INRIA- feb 2012
       double precision rwork(*)
 
       external derivs
-      integer iero
-      common/ierode/iero
 
       lysav=1
       ldysav=lysav+n
       lytemp=ldysav+n
       lwork=lytemp+n
 
-      iero=0
+      ierror=0
       pgrow=-0.20d0
       pshrnk=-0.25d0
       xsav=x
@@ -55,23 +52,25 @@ c     array + blas use. Serge Steer INRIA- feb 2012
 1     hh=0.5*h
       call rk4(rwork(lysav),rwork(ldysav),n,xsav,hh,rwork(lytemp),
      $     derivs,rwork(lwork))
+      if (ierror.gt.0) return
       x=xsav+hh
       call derivs(n,x,rwork(lytemp),dydx)
-      if (iero.gt.0) return 
+      if (ierror.gt.0) return
       call rk4(rwork(lytemp),dydx,n,x,hh,y,derivs,rwork(lwork))
       x=xsav+h
-      if(x.eq.xsav) then 
-         iero=1
+      if(x.eq.xsav) then
+         ierror=1
          return
       endif
       call rk4(rwork(lysav),rwork(ldysav),n,xsav,h,rwork(lytemp),
      $     derivs,rwork(lwork))
+      if (ierror.gt.0) return
       errmax=0.0d0
        do 12 i=0,n-1
         rwork(lytemp+i)=y(i+1)-rwork(lytemp+i)
         errmax=max(errmax,abs(rwork(lytemp+i)/(yscal(i+1)*eps)))
 12    continue
-       
+
       if(errmax.gt.one) then
         h=safety*h*(errmax**pshrnk)
         goto 1
