@@ -1,12 +1,15 @@
 /*
  * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
  * Copyright (C) 2007 - INRIA - Serge STEER
- * 
- * This file must be used under the terms of the CeCILL.
- * This source file is licensed as described in the file COPYING, which
- * you should have received as part of this distribution.  The terms
- * are also available at    
- * http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
+ *
+ * Copyright (C) 2012 - 2016 - Scilab Enterprises
+ *
+ * This file is hereby licensed under the terms of the GNU GPL v2.0,
+ * pursuant to article 5.3.4 of the CeCILL v.2.1.
+ * This file was originally licensed under the terms of the CeCILL v2.1,
+ * and continues to be available under such terms.
+ * For more information, see the COPYING file which you should have received
+ * along with this program.
  *
  */
 
@@ -16,9 +19,7 @@
 #define __ISEQUALVAR__
 
 #include <string.h>
-#include "stack-c.h"
-#include "MALLOC.h"
-#include "stack-def.h"
+#include "sci_malloc.h"
 
 static int IsEqualDoubleMat(double *d1, double *d2);
 static int IsEqualPolyMat(double *d1, double *d2);
@@ -43,16 +44,16 @@ static int IsEqualVar(double *d1, int n1, double *d2, int n2);
 /* comparison mode for double precision numbers */
 void SetDoubleCompMode(int mode);
 int GetDoubleCompMode(void);
-int DoubleCompMode=1; /*IEEE mode */
+int DoubleCompMode = 1; /*IEEE mode */
 
 /* Structure for walking inside Scilab lists (used by IsEqualList)*/
 int AllocRecIfRequired(int krec);
 void FreeRec(void);
 typedef struct RecursionRecord
 {
-  double* d1 ;/* pointers on the first list header */
-  double* d2 ;/* pointers on the second list header */
-  int     k; /* index of current list element  */
+    double* d1 ;/* pointers on the first list header */
+    double* d2 ;/* pointers on the second list header */
+    int     k; /* index of current list element  */
 } RecursionRecord, *RecursionRecordPtr;
 
 RecursionRecordPtr Rrec;
