@@ -2,11 +2,14 @@
  * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
  * Copyright (C) 2012 - Scilab Enterprises - Calixte DENIZET
  *
- * This file must be used under the terms of the CeCILL.
- * This source file is licensed as described in the file COPYING, which
- * you should have received as part of this distribution.  The terms
- * are also available at
- * http://www.cecill.info/licences/Licence_CeCILL_V2.1-en.txt
+ * Copyright (C) 2012 - 2016 - Scilab Enterprises
+ *
+ * This file is hereby licensed under the terms of the GNU GPL v2.0,
+ * pursuant to article 5.3.4 of the CeCILL v.2.1.
+ * This file was originally licensed under the terms of the CeCILL v2.1,
+ * and continues to be available under such terms.
+ * For more information, see the COPYING file which you should have received
+ * along with this program.
  *
  */
 
@@ -171,7 +174,7 @@ int ScilabGateway::invoke_lu(char * fname, const int envId, void * pvApiCtx)
         {
             args[i] = ScilabObjects::getArgumentId(child, tmpvar, false, false, *eId, pvApiCtx);
         }
-        catch (ScilabAbstractEnvironmentException & e)
+        catch (ScilabAbstractEnvironmentException & /*e*/)
         {
             delete[] args;
             delete[] tmpvar;
@@ -188,7 +191,7 @@ int ScilabGateway::invoke_lu(char * fname, const int envId, void * pvApiCtx)
     {
         methName = ScilabObjects::getSingleString(3, pvApiCtx);
     }
-    catch (ScilabAbstractEnvironmentException & e)
+    catch (ScilabAbstractEnvironmentException & /*e*/)
     {
         delete[] args;
         ScilabObjects::removeTemporaryVars(*eId, tmpvar);
@@ -200,7 +203,7 @@ int ScilabGateway::invoke_lu(char * fname, const int envId, void * pvApiCtx)
     {
         ret = env.invoke(idObj, methName, args, nbArgs);
     }
-    catch (std::exception & e)
+    catch (std::exception & /*e*/)
     {
         delete[] args;
         ScilabObjects::removeTemporaryVars(*eId, tmpvar);
@@ -236,11 +239,11 @@ int ScilabGateway::invoke_lu(char * fname, const int envId, void * pvApiCtx)
             {
                 ScilabObjects::createEnvironmentObjectAtPos(EXTERNAL_OBJECT, Rhs + i, ret[i], *eId, pvApiCtx);
             }
-            catch (ScilabAbstractEnvironmentException & e)
+            catch (ScilabAbstractEnvironmentException & /*e*/)
             {
                 if (!torem.empty())
                 {
-                    env.removeobject(&(torem[0]), torem.size());
+                    env.removeobject(&(torem[0]), static_cast<int>(torem.size()));
                 }
                 env.removeobject(ret + 1, *ret);
                 delete[] ret;
@@ -257,7 +260,7 @@ int ScilabGateway::invoke_lu(char * fname, const int envId, void * pvApiCtx)
 
     if (!torem.empty())
     {
-        env.removeobject(&(torem[0]), torem.size());
+        env.removeobject(&(torem[0]), static_cast<int>(torem.size()));
     }
 
     delete[] ret;
