@@ -2,11 +2,14 @@
  * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
  * Copyright (C) 2012 - Scilab Enterprises - Calixte DENIZET
  *
- * This file must be used under the terms of the CeCILL.
- * This source file is licensed as described in the file COPYING, which
- * you should have received as part of this distribution.  The terms
- * are also available at
- * http://www.cecill.info/licences/Licence_CeCILL_V2.1-en.txt
+ * Copyright (C) 2012 - 2016 - Scilab Enterprises
+ *
+ * This file is hereby licensed under the terms of the GNU GPL v2.0,
+ * pursuant to article 5.3.4 of the CeCILL v.2.1.
+ * This file was originally licensed under the terms of the CeCILL v2.1,
+ * and continues to be available under such terms.
+ * For more information, see the COPYING file which you should have received
+ * along with this program.
  *
  */
 
@@ -38,7 +41,7 @@ int ScilabGateway::operation(char * fname, const int envId, const OperatorsType
     {
         eId = ScilabObjects::getEnvironmentId(addr, pvApiCtx);
     }
-    catch (ScilabAbstractEnvironmentException & e)
+    catch (ScilabAbstractEnvironmentException & /*e*/)
     {
         err = getVarAddressFromPosition(pvApiCtx, 2, &addr);
         if (err.iErr)
@@ -71,7 +74,7 @@ int ScilabGateway::operation(char * fname, const int envId, const OperatorsType
         {
             idObjB = ScilabObjects::getArgumentId(addr, tmpvar, false, false, eId, pvApiCtx);
         }
-        catch (std::exception & e)
+        catch (std::exception & /*e*/)
         {
             throw;
         }
@@ -81,7 +84,7 @@ int ScilabGateway::operation(char * fname, const int envId, const OperatorsType
     {
         ret = env.operation(idObjA, idObjB, type);
     }
-    catch (std::exception & e)
+    catch (std::exception & /*e*/)
     {
         ScilabObjects::removeTemporaryVars(eId, tmpvar);
         throw;
@@ -97,7 +100,7 @@ int ScilabGateway::operation(char * fname, const int envId, const OperatorsType
             {
                 ScilabObjects::createEnvironmentObjectAtPos(EXTERNAL_OBJECT, Rhs + 1, ret, eId, pvApiCtx);
             }
-            catch (ScilabAbstractEnvironmentException & e)
+            catch (ScilabAbstractEnvironmentException & /*e*/)
             {
                 env.removeobject(ret);
                 throw;
@@ -114,7 +117,7 @@ int ScilabGateway::operation(char * fname, const int envId, const OperatorsType
         {
             ScilabObjects::createEnvironmentObjectAtPos(EXTERNAL_OBJECT, Rhs + 1, ret, eId, pvApiCtx);
         }
-        catch (ScilabAbstractEnvironmentException & e)
+        catch (ScilabAbstractEnvironmentException & /*e*/)
         {
             env.removeobject(ret);
             throw;
